pub struct ParamSpec {
pub name: String,
pub type: ParamType,
pub required: bool,
pub default: Option<Value>,
pub description: Option<String>,
}Fields
name: Stringtype: ParamTyperequired: booldefault: Option<Value>description: Option<String>Trait Implementations
Sourceimpl Archive for ParamSpec
impl Archive for ParamSpec
Sourcetype Archived = ArchivedParamSpec
type Archived = ArchivedParamSpec
The archived representation of this type. Read more
Sourcetype Resolver = ParamSpecResolver
type Resolver = ParamSpecResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl<'de> Deserialize<'de> for ParamSpec
impl<'de> Deserialize<'de> for ParamSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ParamSpec, __D> for Archived<ParamSpec>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
ParamType: Archive,
<ParamType as Archive>::Archived: Deserialize<ParamType, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
AsJson: ArchiveWith<Option<Value>> + DeserializeWith<<AsJson as ArchiveWith<Option<Value>>>::Archived, Option<Value>, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ParamSpec, __D> for Archived<ParamSpec>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
ParamType: Archive,
<ParamType as Archive>::Archived: Deserialize<ParamType, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
AsJson: ArchiveWith<Option<Value>> + DeserializeWith<<AsJson as ArchiveWith<Option<Value>>>::Archived, Option<Value>, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,