pub struct ResultTemplate {
pub decode: ResultDecode,
pub extract: Option<ResultExtract>,
pub output: String,
pub result_alias: Option<String>,
}Fields
decode: ResultDecodeextract: Option<ResultExtract>output: Stringresult_alias: Option<String>Trait Implementations
Sourceimpl Archive for ResultTemplatewhere
ResultDecode: Archive,
Option<ResultExtract>: Archive,
String: Archive,
Option<String>: Archive,
impl Archive for ResultTemplatewhere
ResultDecode: Archive,
Option<ResultExtract>: Archive,
String: Archive,
Option<String>: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedResultTemplate
type Archived = ArchivedResultTemplate
The archived representation of this type. Read more
Sourcetype Resolver = ResultTemplateResolver
type Resolver = ResultTemplateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ResultTemplate
impl Clone for ResultTemplate
Sourcefn clone(&self) -> ResultTemplate
fn clone(&self) -> ResultTemplate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResultTemplate
impl Debug for ResultTemplate
Sourceimpl Default for ResultTemplate
impl Default for ResultTemplate
Sourceimpl<'de> Deserialize<'de> for ResultTemplate
impl<'de> Deserialize<'de> for ResultTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ResultTemplate, __D> for Archived<ResultTemplate>where
ResultDecode: Archive,
<ResultDecode as Archive>::Archived: Deserialize<ResultDecode, __D>,
Option<ResultExtract>: Archive,
<Option<ResultExtract> as Archive>::Archived: Deserialize<Option<ResultExtract>, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ResultTemplate, __D> for Archived<ResultTemplate>where
ResultDecode: Archive,
<ResultDecode as Archive>::Archived: Deserialize<ResultDecode, __D>,
Option<ResultExtract>: Archive,
<Option<ResultExtract> as Archive>::Archived: Deserialize<Option<ResultExtract>, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ResultTemplate, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ResultTemplate, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl Serialize for ResultTemplate
impl Serialize for ResultTemplate