pub struct RetryTemplate {
pub max_attempts: usize,
pub backoff_ms: u64,
pub retry_on_status: Vec<u16>,
}Fields
max_attempts: usizebackoff_ms: u64retry_on_status: Vec<u16>Trait Implementations
Sourceimpl Archive for RetryTemplate
impl Archive for RetryTemplate
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRetryTemplate
type Archived = ArchivedRetryTemplate
The archived representation of this type. Read more
Sourcetype Resolver = RetryTemplateResolver
type Resolver = RetryTemplateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for RetryTemplate
impl Clone for RetryTemplate
Sourcefn clone(&self) -> RetryTemplate
fn clone(&self) -> RetryTemplate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RetryTemplate
impl Debug for RetryTemplate
Sourceimpl<'de> Deserialize<'de> for RetryTemplate
impl<'de> Deserialize<'de> for RetryTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RetryTemplate, __D> for Archived<RetryTemplate>
impl<__D: Fallible + ?Sized> Deserialize<RetryTemplate, __D> for Archived<RetryTemplate>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RetryTemplate, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RetryTemplate, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl Serialize for RetryTemplate
impl Serialize for RetryTemplate